@@ -178,7 +178,7 @@ class Profile(object):
     def essays(self):
         """
         :returns: An :class:`okcupyd.essay.Essays` instance that is associated with
-        this profile.
+                  this profile.
         """
         return essay.Essays(self)
 
@@ -195,7 +195,7 @@ class Profile(object):
     def match_percentage(self):
         """
         :returns: The match percentage of the logged in user and the user associated
-        with this object.
+                  with this object.
         """
         return int(self._percentages_and_ratings_xpb.
                    div.with_class('match').
@@ -206,7 +206,7 @@ class Profile(object):
     def enemy_percentage(self):
         """
         :returns: The enemy percentage of the logged in user and the user associated
-        with this object.
+                  with this object.
         """
         return int(self._percentages_and_ratings_xpb.
                    div.with_class('enemy').
@@ -248,8 +248,9 @@ class Profile(object):
 
     @util.cached_property
     def attractiveness(self):
-        """:returns: The average attractiveness rating given to this profile by the
-                     okcupid.com community.
+        """
+        :returns: The average attractiveness rating given to this profile by the
+                  okcupid.com community.
         """
         from .attractiveness_finder import AttractivenessFinder
         return AttractivenessFinder(self._session)(self.username)
@@ -279,10 +280,17 @@ class Profile(object):
                                        'headers': dict(self._session.headers)}))
         self.refresh(reload=False)
 
+    def find_question(self, question_id):
+        for question in self.questions:
+            if int(question.id) == int(question_id):
+                return question
+
     def question_fetchable(self, **kwargs):
-        """Return a :class:`okcupyd.util.fetchable.Fetchable` instance that
-        contains objects representing the answers that the user associated with
-        this profile has given to okcupid.com match questions.
+        """
+        :returns: A :class:`okcupyd.util.fetchable.Fetchable` instance that
+                  contains objects representing the answers that the user
+                  associated with this profile has given to okcupid.com match
+                  questions.
         """
         return util.Fetchable(QuestionFetcher(
             self._session, self.username,
