@@ -34,6 +34,32 @@ search_filters.register_filter_builder(
     descriptions=['The minimum age of returned search results.',
                   'The maximum age of returned search results.']
 )
+search_filters.register_filter_builder(
+    magicnumbers.get_kids_filter,
+    keys=('has_kids', 'wants_kids'),
+    acceptable_values=(magicnumbers.maps.has_kids.pattern_to_value.keys(),
+                       magicnumbers.maps.wants_kids.pattern_to_value.keys()),
+    decider=filter.Filters.any_decider
+)
+search_filters.register_filter_builder(
+    magicnumbers.get_question_filter,
+    decider=filter.Filters.any_not_none_decider,
+    types=(':class:`~okcupyd.question.UserQuestion`', 'list[int]'),
+    descriptions=["A question whose answer should be used to match search "
+                  "results, or a question id. If a question id, "
+                  "`question_answers` must be supplied.",
+                  "A list of acceptable question answer indices."]
+)
+search_filters.register_filter_builder(
+    magicnumbers.get_language_query,
+    keys=('language',),
+    acceptable_values=list(magicnumbers.language_map.keys())
+)
+search_filters.register_filter_builder(
+    magicnumbers.get_join_date_filter,
+    types=int,
+    acceptable_values=magicnumbers.join_date_string_to_int.keys()
+)
 
 
 @search_filters.register_filter_builder(
@@ -50,14 +76,20 @@ def attractiveness_filter(attractiveness_min, attractiveness_max):
     return '25,{0},{1}'.format(attractiveness_min, attractiveness_max)
 
 
-@search_filters.register_filter_builder(
+search_filters.register_filter_builder(
+    magicnumbers.get_height_filter,
+    descriptions=["The minimum attractiveness of returned search results.",
+                  "The maximum attractiveness of returned search results."],
+    acceptable_values=["A height int in inches",
+                       "An imperial height string e.g. 5'4\"",
+                       "A metric height string e.g. 1.54m"],
     decider=search_filters.any_not_none_decider
 )
-def height_filter(height_min, height_max):
-    return magicnumbers.get_height_query(height_min, height_max)
 
 
-@search_filters.register_filter_builder
+@search_filters.register_filter_builder(
+    acceptable_values=('day', 'today', 'week', 'month', 'year', 'decade')
+)
 def last_online_filter(last_online):
     return '5,{0}'.format(helpers.format_last_online(last_online))
 
@@ -75,40 +107,26 @@ def status_filter(status):
 def build_option_filter(key):
     @search_filters.register_filter_builder(
         keys=(key,),
-        acceptable_values=magicnumbers.binary_lists[key],
+        acceptable_values=magicnumbers.maps[key].pattern_to_value.keys(),
         types=str
     )
     @util.makelist_decorator
     def option_filter(value):
-        return magicnumbers.get_options_query(key, value)
-
-
-for key in ['smokes', 'drinks', 'drugs', 'education', 'job',
+        return magicnumbers.filters[key](value)
+for key in ['smokes', 'drinks', 'drugs', 'education_level', 'job',
             'income', 'religion', 'monogamy', 'diet', 'sign',
-            'ethnicity']:
+            'ethnicities', 'cats', 'dogs', 'bodytype']:
     build_option_filter(key)
 
 
-         # ('offspring', util.makelist_decorator(magicnumbers.get_kids_query)),
-         # ('join_date', magicnumbers.get_join_date_query),
-         # ('languages', magicnumbers.get_language_query)]
-
-# search_filters.register_filter_builder(
-#     util.makelist_decorator(magicnumbers.get_pet_queries)),
-# keys=('pets',),
-#     types=str,
-# )
-
-
 _username_xpb = xpb.div.with_classes('match_card').\
                 div.with_class('username').a.text_
 def SearchFetchable(session=None, **kwargs):
     """Search okcupid.com with the given parameters.
 
-    :returns: A :class:`okcupyd.util.fetchable.Fetchable` of
-              :class:`okcupyd.profile.Profile` instances.
+    :returns: A :class:`~okcupyd.util.fetchable.Fetchable` of
+              :class:`~okcupyd.profile.Profile` instances.
     """
-
     session = session or Session.login()
     return util.Fetchable.fetch_marshall(
         SearchHTMLFetcher(session, **kwargs),
@@ -130,24 +148,14 @@ class SearchHTMLFetcher(object):
     def __init__(self, session=None, **options):
         self._session = session or Session.login()
         self._options = options
+        self.location = self._options.pop('location', None)
+        self.gender = self._options.pop('gender', 'm')
+        self.keywords = self._options.pop('keywords', None)
+        self.order_by = self._options.pop('order_by', 'match').upper()
+        self.count = self._options.pop('count', 9)
+        self.filters = search_filters.build(**self._options)
 
-    @property
-    def location(self):
-        return self._options.get('location', None)
-
-    @property
-    def gender(self):
-        return self._options.get('gender', 'm')
-
-    @property
-    def keywords(self):
-        return self._options.get('keywords')
-
-    @property
-    def order_by(self):
-        return self._options.get('order_by', 'match').upper()
-
-    def _query_params(self, count=None, low=None):
+    def _query_params(self, low=None):
         search_parameters = {
             'timekey': 1,
             'matchOrderBy': self.order_by,
@@ -157,7 +165,7 @@ class SearchHTMLFetcher(object):
             'update_prefs': '1',
             'sort_type': '0',
             'sa': '1',
-            'count': str(count) if count else self._options.get('count', 9),
+            'count': self.count,
             'locid': (str(helpers.get_locid(self._session, self.location))
                       if self.location else 0),
             'ajax_load': 1,
@@ -167,11 +175,11 @@ class SearchHTMLFetcher(object):
         if low:
             search_parameters['low'] = low
         if self.keywords: search_parameters['keywords'] = self.keywords
-        search_parameters.update(search_filters.build(**self._options))
+        search_parameters.update(self.filters)
         return search_parameters
 
     def fetch(self, start_at=None, count=None):
-        search_parameters = self._query_params(low=start_at, count=count)
+        search_parameters = self._query_params(low=start_at)
         log.info(simplejson.dumps({'search_parameters': search_parameters}))
         response = self._session.okc_get('match',
                                          params=search_parameters)
